===========
Regressors
===========

.. toctree::
   :maxdepth: 1

   CatBoost Regressor <regressors/cb>
   LightGBM Regressor <regressors/lgbm>
   Linear Regressor <regressors/linear>
   NN Regressor <regressors/nn>
   Random Forest Regressor <regressors/random_forest>
   Support Vector Regressor <regressors/support_vector>
